@@ -19,6 +19,16 @@ from fuo_bilibili.util import format_timedelta_to_hms
 PROVIDER_ID = __identifier__
 
 
+def get_text_from_html(html):
+    return BeautifulSoup(html, features="html.parser").get_text()
+
+
+def wrap_pic(pic):
+    if pic.startswith('//'):
+        return f'http:{pic}'
+    return pic
+
+
 class BBriefAlbumModel(BriefAlbumModel):
     cover: str = ''
 
@@ -108,7 +118,7 @@ class BSongModel(SongModel):
                 title=page.part,
                 artists=[],
                 duration=page.duration.total_seconds() * 1000,
-                pic_url=result.pic,
+                pic_url=wrap_pic(result.pic),
             )
             children.append(song)
 
@@ -130,7 +140,7 @@ class BSongModel(SongModel):
             )],
             duration=result.duration.total_seconds() * 1000,
             lyric=lrc or '',
-            pic_url=result.pic,
+            pic_url=wrap_pic(result.pic),
             children=children,
         )
 
@@ -225,10 +235,10 @@ class BSearchModel:
 
     @classmethod
     def create_model(cls, request: SearchRequest, response: Union[SearchResponse, Tuple[SearchResponse]]):
-        songs = None
-        artists = None
-        videos = None
-        albums = None
+        songs = []
+        artists = []
+        videos = []
+        albums = []
         if isinstance(response, Tuple):
             results = []
             for r in response:
@@ -238,15 +248,16 @@ class BSearchModel:
         else:
             results = response.data.result or []
         # fixme: implements multiple search types
-        match SearchType.BANGUMI if isinstance(request, Tuple) else request.search_type:
-            case SearchType.VIDEO:
-                songs = list(map(lambda r_: BSongModel.create_model(r_), results))
-            case SearchType.BILI_USER:
-                artists = list(map(cls.search_user_model, results))
-            case SearchType.LIVE_ROOM:
-                videos = list(map(cls.search_live_model, results))
-            case SearchType.BANGUMI:
-                albums = list(map(cls.search_media_model, results))
+        for result in results:
+            if isinstance(result, SearchResultVideo):
+                songs.append(BSongModel.create_model(result))
+                videos.append(BVideoModel.create_video_model(result))
+            elif isinstance(result, SearchResultUser):
+                artists.append(cls.search_user_model(result))
+            elif isinstance(result, SearchResultLiveRoom):
+                videos.append(cls.search_live_model(result))
+            elif isinstance(result, SearchResultMedia):
+                albums.append(cls.search_media_model(result))
         return SimpleSearchResult(
             q=request[0].keyword if isinstance(request, Tuple) else request.keyword,
             songs=songs or [],
@@ -477,3 +488,21 @@ class BVideoModel(VideoModel):
             duration=0,
             cover=live.cover,
         )
+
+    @classmethod
+    def create_video_model(cls, result: SearchResultVideo) -> 'VideoModel':
+        return VideoModel(
+            source=__identifier__,
+            identifier=result.bvid,
+            title=get_text_from_html(result.title),
+            artists=[BriefArtistModel(
+                source=__identifier__,
+                name=result.author,
+                identifier=result.mid
+            )],
+            duration=result.duration.total_seconds(),
+            cover=wrap_pic(result.pic),
+            play_count=result.play,
+            released=result.pubdate.strftime('%Y-%m-%d'),
+        )
+
