@@ -32,7 +32,8 @@ from fuo_bilibili.model import BSearchModel, BSongModel, BPlaylistModel, BArtist
 from fuo_bilibili.util import json_to_lrc_text
 
 SEARCH_TYPE_MAP = {
-    FuoSearchType.vi: BilibiliSearchType.LIVE_ROOM,  # 对应直播间
+    # 对应直播间
+    FuoSearchType.vi: BilibiliSearchType.LIVE_ROOM,
     FuoSearchType.ar: BilibiliSearchType.BILI_USER,  # 对应B站用户
     FuoSearchType.so: BilibiliSearchType.VIDEO,  # 对应投稿视频
     FuoSearchType.al: (BilibiliSearchType.MEDIA, BilibiliSearchType.BANGUMI),  # 对应番剧电影
@@ -100,7 +101,7 @@ class BilibiliProvider(AbstractProvider, ProviderV2, SupportsSongSimilar, Suppor
             ModelType.album: (Pf.model_v2 | Pf.get),
         }
 
-    def __init__(self):
+    def __init__(self, enable_live_room_as_video=True):
         super(BilibiliProvider, self).__init__()
         self._api = BilibiliApi()
         self._user = None
@@ -108,8 +109,13 @@ class BilibiliProvider(AbstractProvider, ProviderV2, SupportsSongSimilar, Suppor
         self._video_cids = dict()
         self._video_avids = dict()
 
+        self.enable_live_room_as_video = enable_live_room_as_video
+
     def _format_search_request(self, keyword, type_) -> Union[SearchRequest, Tuple[SearchRequest]]:
-        btype = SEARCH_TYPE_MAP.get(type_)
+        if self.enable_live_room_as_video is False and type_ == FuoSearchType.vi:
+            btype = BilibiliSearchType.VIDEO
+        else:
+            btype = SEARCH_TYPE_MAP.get(type_)
         if btype is None:
             raise NotImplementedError
         if isinstance(btype, Tuple):
@@ -124,17 +130,8 @@ class BilibiliProvider(AbstractProvider, ProviderV2, SupportsSongSimilar, Suppor
     def request_key(self) -> RequestLoginKeyResponse:
         return self._api.request_login_key()
 
-    def cookie_check(self):
-        return self._api.cookie_check()
-
-    def auth(self, _):
-        self._api.load_cookies()
-        try:
-            self._user = self.user_info()
-        except RuntimeError as re:
-            self._api.remove_cookie()
-            print(str(re) + ' 请重新登录')
-        return self._user
+    def auth(self, user):
+        self._user = user
 
     def has_current_user(self) -> bool:
         return self._user is not None
@@ -345,7 +342,6 @@ class BilibiliProvider(AbstractProvider, ProviderV2, SupportsSongSimilar, Suppor
         if audios is None or len(audios) == 0:
             return None
         # select video
-        print(response.data.dash.video)
         max_quality_code = VideoQualityNum.get_max_from_quality(quality)
         select_quality = max(filter(lambda c: c.value <= max_quality_code, self._video_quality_codes[video.identifier]),
                              key=lambda c: c.value)
